from rest_framework import status

class HTTPStatusTestCaseMixin(object):

    def assertHTTP200(self, response):
        self.assertEqual(response.status_code, status.HTTP_200_OK)

    def assertHTTP201(self, response):
        self.assertEqual(response.status_code, status.HTTP_201_CREATED)

    def assertHTTP401(self, response):
        self.assertEqual(response.status_code, status.HTTP_401_UNAUTHORIZED)

    def assertHTTP403(self, response):
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)



from rest_framework import exceptions
import django_filters


class EnumFilter(django_filters.filters.BaseInFilter, django_filters.filters.MethodFilter):

    def __init__(self, enum, *args, **kwargs):
        self.enum = enum

        if 'action' not in kwargs:
            kwargs.update(action=self.filter_enum)

        super(EnumFilter, self).__init__(*args, **kwargs)

    def filter_enum(self, queryset, values):
        for k, value in enumerate(values):
            try:
                values[k] = self.enum.get(value).value
            except AttributeError:
                raise exceptions.ValidationError(detail={self.name: ['Invalid']})

        if values:
            filters = {'{}__in'.format(self.name): values}
            return queryset.filter(**filters)
        else:
            return queryset



from rest_framework.throttling import ScopedRateThrottle


class ScopedActionRateThrottle(ScopedRateThrottle):

    def __call__(self, *args, **kwargs):
        return self

    def __init__(self, action, scope):
        self.action = action
        self.scope_attr = 'throttle_{}_{}_scope'.format(action, scope)

    def allow_request(self, request, view):
        if view.action == self.action:
            return super(ScopedActionRateThrottle, self).allow_request(request, view)

        return True





class MeaspkViewSetMixin(object):

    def initial(self, request, *args, **kwargs):
        if kwargs.get('pk') == 'me':
            kwargs['pk'] = request.user.pk

        for k, v in kwargs.items():
            if k.startswith('parent_lookup_') and v == 'me':
                kwargs[k] = request.user.pk

        self.kwargs = kwargs

        super(MeaspkViewSetMixin, self).initial(request, *args, **kwargs)
